@@ -60,6 +60,17 @@ bool Settings::zoomEnabled()
     return m_zoomEnabled;
 }
 
+void Settings::setStretchEnabled( bool enabled )
+{
+    m_stretchEnabled = enabled;
+    saveSettings();
+}
+
+bool Settings::stretchEnabled()
+{
+    return m_stretchEnabled;
+}
+
 void Settings::setFrameDropEnabled( bool enabled )
 {
     m_frameDropEnabled = enabled;
@@ -75,6 +86,7 @@ void Settings::saveSettings()
 {
     m_settings->setValue( KEY_INIT, true );
     m_settings->setValue( KEY_ZOOMENABLED, m_zoomEnabled );
+    m_settings->setValue( KEY_STRETCHENABLED, m_stretchEnabled );
     m_settings->setValue( KEY_FRAMEDROPENABLED, m_frameDropEnabled );
     m_settings->remove( PREFIX_SEARCHFOLDERS );
     m_settings->beginWriteArray( PREFIX_SEARCHFOLDERS );
@@ -89,7 +101,8 @@ void Settings::loadSettings()
 {
     m_initialized = m_settings->value( KEY_INIT ).toBool();
     m_zoomEnabled = m_settings->value( KEY_ZOOMENABLED ).toBool();
-    m_frameDropEnabled = m_settings->value( KEY_FRAMEDROPENABLED, true ).toBool();
+    m_stretchEnabled = m_settings->value( KEY_STRETCHENABLED ).toBool();
+    m_frameDropEnabled = m_settings->value( KEY_FRAMEDROPENABLED, false ).toBool();
     int size =  m_settings->beginReadArray( PREFIX_SEARCHFOLDERS );
     for ( int i = 0; i < size; i++ ) {
         m_settings->setArrayIndex( i );
