@@ -17,6 +17,7 @@ const QString PREFIX_SEARCHFOLDERS( "Folders" );
 const QString PREFIX_FILES( "Files" );
 const QString KEY_INIT( "initialized" );
 const QString KEY_ZOOMENABLED( "zoom" );
+const QString KEY_STRETCHENABLED( "stretch" );
 const QString KEY_FRAMEDROPENABLED( "framedrop" );
 const QString KEY_FOLDER( "folder" );
 const QString KEY_FILENAME( "file" );
@@ -34,6 +35,8 @@ public:
     void removeFolder( QString folder );
     void setZoomEnabled( bool enabled );
     bool zoomEnabled();
+    void setStretchEnabled( bool enabled );
+    bool stretchEnabled();
     void setFrameDropEnabled( bool enabled );
     bool frameDropEnabled();
 
@@ -52,6 +55,9 @@ private:
         /// indicates if mplayer zoom is enabled
         bool m_zoomEnabled;
 
+        /// indicates if mplayer stretch is enabled
+        bool m_stretchEnabled;
+
         /// indicates if mplayer frame drop is enabled
         bool m_frameDropEnabled;
 };
