@@ -88,7 +88,8 @@ void SiBApplication::playFile( int idx )
     m_player->playFile(
         m_fileList->file( idx ),
         m_settings->zoomEnabled(),
-        m_settings->frameDropEnabled() );
+        m_settings->frameDropEnabled(),
+        m_settings->stretchEnabled() );
 }
 
 void SiBApplication::restartFile( int idx )
