@@ -11,8 +11,8 @@
 #include <QtCore/qobject.h>
 #include "mainwindow.h"
 #include "Settings.h"
+#include "filelist.h"
 
-class FileList;
 class PlayerFacade;
 
 class SiBApplication : public QObject {
@@ -39,6 +39,11 @@ public:
      */
     void refreshFileList();
 
+    /**
+     * Sorts the list model.
+     */
+    void sortFileList( FileList::SortCriteria criteria, Qt::SortOrder order );
+
     void playFile( int idx );
 
     void restartFile( int idx );
