@@ -7,21 +7,36 @@
 class VideoFile;
 class QDir;
 class QFileInfo;
+class FileSearchDialog;
+
 typedef QList<QFileInfo> QFileInfoList;
 
 class FileList : public QObject
 {
-	Q_OBJECT;
+    Q_OBJECT;
+
+public:
+
+    enum SortCriteria {
+        ESortByName,
+        ESortBySize,
+        ESortByResumePos
+    };
 
 public:
     FileList( QObject* parent );
     ~FileList();
 
 public:
-    void searchFiles( const QList<QString>& searchFolders );
+    void searchFiles( const QList<QString>& searchFolders, FileSearchDialog& parent );
     const QList<VideoFile*>& files();
     VideoFile* file( int idx );
 
+    /**
+     * Sorts the files on given criteria and order.
+     */
+    void sortFileList( SortCriteria criteria, Qt::SortOrder order );
+
 private:
 
     void updateFileList( const QFileInfoList& files );
@@ -29,7 +44,7 @@ private:
     /**
      * Searches files recursively in given dir.
      */
-    void getFilesInDir( const QDir& dir, QFileInfoList& fileList );
+    void getFilesInDir( const QDir& dir, QFileInfoList& fileList, FileSearchDialog& progress );
 
     void loadFileList();
     void saveFileList();
@@ -37,6 +52,8 @@ private:
 private:
     QList<VideoFile*> m_files;
     QStringList m_knownExtensions;
+    SortCriteria m_sortCriteria;
+    Qt::SortOrder m_sortOrder;
 };
 
 #endif // FILELIST_H
