@@ -151,7 +151,9 @@ void MainWindow::settingsButtonPressed()
 {
     SettingsDlg settingsDlg;
     settingsDlg.exec();
-    SiBApplication::instance()->updateFileList();
+    if ( settingsDlg.updateFileList() ) {
+        SiBApplication::instance()->updateFileList();
+    }
 }
 
 void MainWindow::helpButtonPressed()
@@ -230,9 +232,6 @@ void MainWindow::playerStart()
 void MainWindow::playerStop()
 {
 	m_playbutton->setText( tr( "Start" ) );
-#if 0
-	cellClicked( m_fileList->currentRow(), m_fileList->currentColumn() );
-#endif
 }
 
 QString MainWindow::toHHMMSS( unsigned int tenthOfASec )
