@@ -108,6 +108,10 @@ void PlayerFacade::doPlayFile()
         arguments << "-vf";
         arguments << m_zoomOptions;
     }
+    if ( m_stretch ) {
+        arguments << "-aspect";
+        arguments << "15:9";
+    }
     if ( m_frameDrop ) {
         arguments << "-framedrop";
     }
@@ -119,7 +123,7 @@ void PlayerFacade::doPlayFile()
     }
 }
 
-void PlayerFacade::playFile( VideoFile* file, bool zoom, bool frameDropEnabled )
+void PlayerFacade::playFile( VideoFile* file, bool zoom, bool frameDropEnabled, bool stretchEnabled )
 {
     if ( !file || m_playerIsRunning  ) {
         return;
@@ -128,10 +132,11 @@ void PlayerFacade::playFile( VideoFile* file, bool zoom, bool frameDropEnabled )
     m_zoomOptions = tr( "" );
 
     m_frameDrop = frameDropEnabled;
+    m_stretch = stretchEnabled;
 
     m_currentFile = file;
 
-    if ( zoom ) {
+    if ( zoom && !m_stretch ) {
         setZoomOptions();
     } else {
         doPlayFile();
