@@ -28,7 +28,7 @@ signals:
     void playerStop();
 
 public:
-    void playFile( VideoFile* file, bool zoom, bool frameDropEnabled );
+    void playFile( VideoFile* file, bool zoom, bool frameDropEnabled, bool stretchEnabled );
     bool isPlayerRunning();
     void stop();
 
@@ -39,8 +39,6 @@ public:
 
 private:
 
-
-
     /**
      * Starts MPlayer to retrieve the video dimensions and
      * then calculates the crop dimensions.
@@ -53,6 +51,7 @@ private:
     bool m_playerIsRunning;
     QString m_zoomOptions;
     bool m_frameDrop;
+    bool m_stretch;
 };
 
 #endif // PLAYERFACADE_H
