@@ -14,19 +14,18 @@ public:
     SettingsDlg( QWidget *parent = 0 );
     ~SettingsDlg();
 
+    bool updateFileList();
+
 private slots:
 
-    void addFolderButtonClicked();
-    void removeFolderButtonClicked();
-    void cellClicked();
+    void selectFolders();
     void zoomEnabled( bool enabled );
+    void stretchEnabled( bool enabled );
     void frameDropEnabled( bool enabled );
 
-private:
-    void setupFolderList();
-
 private:
     Ui::SettingsDlgClass ui;
+    bool m_updateFileList;
 };
 
 #endif // SETTINGSDLG_H
